# py_modules
from setuptools import setup

setup(
    version='0.0.1',
    include_package_data=True,
    name='otpcrack',
    discription="This otpcrack tool can be used for crack the OTP.",
    long_discription="You can type otpcrack on terminal and give detyails like url , input identity , input type which you are giving in input identity and a submit button identity at last give the submit type which you are giving in submit identity. The optional perameter you can give the method as the data can flow or gone by get or post method.",
    short_discription="you can starty or anymajor help by type otpcrack =h or --help to show the help.",
    author='Sahaj',
    py_modules=['tool'],
    install_requires=['requests', 'bs4' , 'argparse' ,'urllib3'],
    entry_points={
        'console_scripts':[
            'otpcrack=tool:main'
        ]
    }
)